package com.gic.enterprise.service.outer.impl;

import com.gic.api.base.commons.ServiceResponse;
import com.gic.commons.util.EntityUtil;
import com.gic.enterprise.dto.data.DataMemberConsumeConfigDTO;
import com.gic.enterprise.entity.TabDataMemberConsumeConfig;
import com.gic.enterprise.error.ErrorCode;
import com.gic.enterprise.service.DataConfigApiService;
import com.gic.enterprise.service.DataMemberConsumeConfigService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

@Service("dataConfigApiService")
public class DataConfigApiServiceImpl implements DataConfigApiService {
    @Autowired
    private DataMemberConsumeConfigService dataMemberConsumeConfigService;

    @Override
    public ServiceResponse<Integer> configMemberConsume(DataMemberConsumeConfigDTO dto) {
        if (dto.getEnterpriseId() == null) {
            return ServiceResponse.failure(ErrorCode.PARAMETER_ERROR.getCode(), "商户ID不能为空");
        }
        TabDataMemberConsumeConfig record = dataMemberConsumeConfigService.getByEnterpriseId(dto.getEnterpriseId());
        if (record == null) {
            //还未配置，新增
            return ServiceResponse.success(dataMemberConsumeConfigService.saveMemberConsumeConfig(dto));
        }
        dto.setMemberConsumeConfigId(record.getMemberConsumeConfigId());
        dataMemberConsumeConfigService.editMemberConsumeConfig(dto);
        return ServiceResponse.success(record.getMemberConsumeConfigId());
    }

    @Override
    public ServiceResponse<DataMemberConsumeConfigDTO> getMemberConsumeConfigByEnterpriseId(Integer enterpriseId) {
        TabDataMemberConsumeConfig record = dataMemberConsumeConfigService.getByEnterpriseId(enterpriseId);
        if (record == null) {
            //还未配置，新增
            return ServiceResponse.failure(ErrorCode.PARAMETER_ERROR.getCode(), "还未配置会员消费规则");
        }
        return ServiceResponse.success(EntityUtil.changeEntityNew(DataMemberConsumeConfigDTO.class, record));
    }
}
